
/**
 * <p>Title: Peak.java </p>
 * <p>Description: Peaks used by the Generic Hump functions </p>
 * <p>Copyright: Copyright (c) 28/05/2009</p>
 * <p>Institute: School of Computer Science and IT, RMIT University</p>
 * @author Xiaodong Li (xiaodong.li@rmit.edu.au)
 * @version 1.0
 * This is the implementation of the rpso algorithms described in the following paper:
 * Li, X. (2010), "Niching without Niching Parameters: Particle Swarm Optimization using a Ring Topology", 
 * IEEE Transactions on Evolutionary Computation,  Volume 14, No.1, February 2010, pp.150-169.
 * For more information, please refer to: http://goanna.cs.rmit.edu.au/~xiaodong/
 * You need to have RePast 3.1 installed on your machine in order to compile and run the program. 
 * For more informaton on RePast, see: http://repast.sourceforge.net/repast_3/index.html
 */
 
import java.util.*;
import uchicago.src.sim.gui.*;
import uchicago.src.sim.space.*;
import java.lang.Math.*;


// If an agent, or any other object is to be displayed in a display it
// needs to implement at least the drawable interface which has one method:
// draw(SimGraphics g)
public class Peak implements Drawable {

  // ---------------------------------------------------------------- Members

  /** Two coordindates (x, y) represent this agent on the 2-dimensional lattice **/
  protected int x, y;

  /** The location vector **/
  protected double[] location;

  /** The radius r **/
  protected double r;
  
  /** The model associated with this agent **/
  private PSOModel model;
 
  public Peak(PSOModel model) {
    // Copy the space and model
    this.model = model;
  
    // Initalize the arrays
    location = new double[model.getDimension()];
            
    double locationL = 0.0;
    double locationU = 1.0;
 
    // Randomly initialize the location 
    for (int i=0; i < model.getDimension(); i++) 
         location[i] = (locationU - locationL) * model.getRandomUniform() + locationL;
    r = (locationU - locationL) * model.getRandomUniform() + locationL;
    
    //r = 0.29; // 5 dimensions
    //r = 0.6; // 10 dimensions
    //r = 1.45; // 25 dimensions
    
  }

 
  /**
   * Set the xy-coordinates of the agent
   * @param x
   * @param y
   */
  public void setXY(int x, int y) {
   this.x = x;
   this.y = y;
 
  }

  /**
   * Return x-coordinate
   * @return
   */
  public int getX() {
    return x;
  }

  /**
   * Return y-coordinate
   * @return
   */
  public int getY() {
    return y;
  }
  
   public double[] getLocation() {
       return location;
   }
     
   public void setLocation(double[] x) {
       for (int j=0; j < model.getDimension(); j++)
        location[j] = x[j];
   }

   public double getR() {
       return r;
   }
 
   public void setR(double r) {
       this.r = r;
   }
 
 
   
  /**
   * Drawable implementationdraw() is called whenever the display is updated,
   * assuming the agent is part of what is being displayed.
   */
  public void draw(SimGraphics g) {
    g.drawFastRoundRect(java.awt.Color.red);
  }
  
}
